@@ -6,13 +6,15 @@
 //!
 //! > A DynamoDb implementation of the `EventStore` trait in [cqrs-es](https://crates.io/crates/persist-es).
 //!
+pub use crate::cqrs::*;
 pub use crate::event_repository::*;
-pub use crate::event_repository::*;
-pub use crate::query_repository::*;
 pub use crate::types::*;
+pub use crate::view_repository::*;
 
+mod cqrs;
 mod error;
 mod event_repository;
-mod query_repository;
+mod helpers;
 mod testing;
 mod types;
+mod view_repository;
